Glossary
--------

object:
   A collection of related data that comes with a set of functions that
   operate on it. The objects we have used so far are the ``cout``
   object provided by the system, and ``string``\ s.

index:
   A variable or value used to select one of the members of an ordered
   set, like a character from a string.

traverse:
   To iterate through all the elements of a set performing a similar
   operation on each.

counter:
   A variable used to count something, usually initialized to zero and
   then incremented.

increment:
   Increase the value of a variable by one. The increment operator in
   C++ is ``++``. In fact, that’s why C++ is called C++, because it is
   meant to be one better than C.

decrement:
   Decrease the value of a variable by one. The decrement operator in
   C++ is ``–``.

concatenate:
   To join two operands end-to-end.


.. dragndrop:: chapter_seven_glossary
    :feedback: Try again!
    :match_1:  object|||A collection of related data that comes with a set of functions that operate on it.
    :match_2: index|||A variable or value used to select one of the members of an ordered set, like a character from a string.
    :match_3: traverse|||To iterate through all the elements of a set performing a similar operation on each.
    :match_4: counter|||A variable used to count something.
    :match_5: increment|||Increase the value of a variable by one.
    :match_6: decrement|||Decrease the value of a variable by one.
    :match_7: concatenate|||To join two operands end-to-end.


    Match the definition to the term.